ExternalSchemaAdapter class abstract

Adapter contract for translating external schema formats into KnexSchemaAst.

Implementers

Constructors

ExternalSchemaAdapter()

Properties

formatId String
Human-readable format id, e.g. json-schema.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canParse(dynamic input) bool
Whether this adapter can parse the given input.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic input) KnexSchemaAst
Parse input and produce canonical Knex schema AST.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited