MigrationConfig class

Migration configuration

Constructors

MigrationConfig({String directory = './migrations', String tableName = 'knex_migrations', String? schemaName, bool disableTransactions = true})
const

Properties

directory String
Directory containing migration files
final
disableTransactions bool
Disable transaction wrapping for each migration step.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaName String?
Schema name for migration table
final
tableName String
Table name for storing migration state
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited