MigrationSource class abstract

Source abstraction for loading migration units.

Examples:

  • in-memory code registrations
  • filesystem SQL directories
  • external schema adapters projected into migration units
Implementers

Constructors

MigrationSource()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

load(Knex knex) Future<List<MigrationUnit>>
Loads migration units from this source.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited