MigrationUnit class abstract

One executable migration unit with an explicit name and reversible steps.

This is the runtime contract used by the migrator engine.

Implementers

Constructors

MigrationUnit()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Stable migration identifier used for ordering and persistence.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

down(Knex knex) Future<void>
Reverts the migration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
up(Knex knex) Future<void>
Applies the migration.

Operators

operator ==(Object other) bool
The equality operator.
inherited