QueryEvent class

Event emitted when a query is executed

Constructors

QueryEvent({required String sql, required List bindings, required String uid, String? txId})
const

Properties

bindings List
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sql String
final
txId String?
final
uid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited