Ref class

Column reference that should behave like a Raw fragment

accepted and benefits from wrapping/UID handling in Raw.toSQL().

Inheritance

Constructors

Ref(Client client, String ref)

Properties

bindings → dynamic
Get the bindings
no setterinherited
client Client
Get the client
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isRawInstance bool
Flag to identify Raw instances
no setterinherited
ref String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sql String
Get the SQL string
no setterinherited

Methods

as(String alias) Ref
Set an alias for this reference
execute() Future
Execute this raw query
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String sql, [dynamic bindings]) Raw
Set the SQL and bindings for this raw query
inherited
then(dynamic onValue(dynamic value), {Function? onError}) Future
Alias for execute
inherited
toSQL() SqlString
Format this reference using the client's identifier wrapper
override
toString() String
A string representation of this object.
override
withSchema(String schema) Ref
Set schema for this reference
wrap(String before, String after) Raw
Wrap this raw query with before/after strings
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited