ExternalSchemaAdapter class abstract
Adapter contract for translating external schema formats into KnexSchemaAst.
- Implementers
Constructors
Properties
Methods
-
canParse(
dynamic input) → bool -
Whether this adapter can parse the given
input. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
dynamic input) → KnexSchemaAst - Parse input and produce canonical Knex schema AST.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited