MigrationUnit class abstract
One executable migration unit with an explicit name and reversible steps.
This is the runtime contract used by the migrator engine.
- Implementers
Constructors
Properties
Methods
-
down(
Knex knex) → Future< void> - Reverts the migration.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
up(
Knex knex) → Future< void> - Applies the migration.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited