QueryEvent class
Event emitted when a query is executed
Constructors
- QueryEvent({required String sql, required List bindings, required String uid, String? txId})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited