SqlString class
Represents a compiled SQL query with its bindings
Properties
- bindings → List
-
The parameter bindings for the query
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- method → String?
-
Method type (select, insert, update, delete, etc.)
final
- pluck → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sql → String
-
The SQL query string with placeholders
final
- uid → String?
-
final
Methods
-
copyWith(
{String? sql, List? bindings, String? method, String? pluck}) → SqlString - Create a copy with different values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Convert to a map representation
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override